@@ -208,7 +208,7 @@ them from 1 to however many are sent.")
                                       (when (search-backward-regexp
                                              complete-rx
                                              nil t)
-                                        (pos-eol)))))
+                                        (line-end-position)))))
         (when end-pos
           (let ((all-lines (seq-filter
                             (lambda (line) (string-match-p complete-rx line))
